netapp_ontap.resources.wwpn_alias API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.wwpn_alias`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

A worldwide port name (WWPN) is a unique 64-bit identifier for a Fibre Channel (FC) initiator. It is displayed as a 16-character hexadecimal value. SAN administrators might find it easier to identify FC initiators using an alias, especially in larger SANs.
The WWPN alias REST API allows you to create, delete, and discover aliases for WWPNs.
Multiple aliases can be created for a WWPN, but you cannot use the same alias for multiple WWPNs.
An alias can consist of up to 32 characters. Valid characters are:

- A through Z
- a through z
- numbers 0 through 9
- hyphen ("-")
- underscore ("_")
- left and right braces ("{", "}")
- period (".")

## Examples

### Creating a WWPN alias

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import WwpnAlias

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = WwpnAlias()
        resource.svm.name = "svm1"
        resource.wwpn = "50:0a:09:82:b4:30:25:05"
        resource.alias = "alias3"
        resource.post(hydrate=True)
        print(resource)

### Retrieving all properties of all WWPN aliases

The `fields` query parameter is used to request that all properties be returned.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import WwpnAlias

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(WwpnAlias.get_collection(fields="*")))

Try it out

    [
        WwpnAlias(
            {
                "svm": {
                    "uuid": "68589d3d-7efa-11e8-9eed-005056b43025",
                    "name": "svm1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/68589d3d-7efa-11e8-9eed-005056b43025"
                        }
                    },
                },
                "_links": {
                    "self": {
                        "href": "/api/network/fc/wwpn-aliases/68589d3d-7efa-11e8-9eed-005056b43025/alias1"
                    }
                },
                "wwpn": "20:00:00:50:56:b4:30:25",
                "alias": "alias1",
            }
        ),
        WwpnAlias(
            {
                "svm": {
                    "uuid": "68589d3d-7efa-11e8-9eed-005056b43025",
                    "name": "svm1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/68589d3d-7efa-11e8-9eed-005056b43025"
                        }
                    },
                },
                "_links": {
                    "self": {
                        "href": "/api/network/fc/wwpn-aliases/68589d3d-7efa-11e8-9eed-005056b43025/alias2"
                    }
                },
                "wwpn": "50:0a:09:82:b4:30:25:00",
                "alias": "alias2",
            }
        ),
    ]

### Retrieving all WWPN aliases named "alias1"

The `alias` query parameter is used to specify a query for the value "alias1".

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import WwpnAlias

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(WwpnAlias.get_collection(alias="alias1")))

Try it out

    [
        WwpnAlias(
            {
                "svm": {
                    "uuid": "68589d3d-7efa-11e8-9eed-005056b43025",
                    "name": "svm1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/68589d3d-7efa-11e8-9eed-005056b43025"
                        }
                    },
                },
                "_links": {
                    "self": {
                        "href": "/api/network/fc/wwpn-aliases/68589d3d-7efa-11e8-9eed-005056b43025/alias1"
                    }
                },
                "wwpn": "20:00:00:50:56:b4:30:25",
                "alias": "alias1",
            }
        )
    ]

### Retrieving a specific WWPN alias

The alias to be returned is identified by the UUID of its SVM and the alias name.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import WwpnAlias

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = WwpnAlias(
            alias="alias2", **{"svm.uuid": "68589d3d-7efa-11e8-9eed-005056b43025"}
        )
        resource.get()
        print(resource)

Try it out

    [
        WwpnAlias(
            {
                "svm": {
                    "uuid": "68589d3d-7efa-11e8-9eed-005056b43025",
                    "name": "svm1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/68589d3d-7efa-11e8-9eed-005056b43025"
                        }
                    },
                },
                "_links": {
                    "self": {
                        "href": "/api/network/fc/wwpn-aliases/68589d3d-7efa-11e8-9eed-005056b43025/alias1"
                    }
                },
                "wwpn": "50:0a:09:82:b4:30:25:00",
                "alias": "alias2",
            }
        )
    ]

### Deleting a WWPN alias

The alias to delete is identified by the UUID of its SVM and the alias name.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import WwpnAlias

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = WwpnAlias(
            alias="alias2", **{"svm.uuid": "68589d3d-7efa-11e8-9eed-005056b43025"}
        )
        resource.delete()

## Classes

`class WwpnAlias (*args, **kwargs)`

  A Fibre Channel (FC) world wide port name (WWPN) alias. A WWPN is a unique 64-bit identifier for an FC initiator. It is displayed as a 16-character hexadecimal value. SAN administrators may find it easier to identify FC initiators using an alias, especially in larger SANs.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves FC WWPN aliases.

    ### Related ONTAP commands

    - `vserver fcp wwpn-alias show`

    ### Learn more

    - `DOC /network/fc/wwpn-aliases`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes an FC WWPN alias.

    ### Related ONTAP commands

    - `vserver fcp wwpn-alias remove`

    ### Learn more

    - `DOC /network/fc/wwpn-aliases`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves FC WWPN aliases.

    ### Related ONTAP commands

    - `vserver fcp wwpn-alias show`

    ### Learn more

    - `DOC /network/fc/wwpn-aliases`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves FC WWPN aliases.

    ### Related ONTAP commands

    - `vserver fcp wwpn-alias show`

    ### Learn more

    - `DOC /network/fc/wwpn-aliases`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes an FC WWPN alias.

    ### Related ONTAP commands

    - `vserver fcp wwpn-alias remove`

    ### Learn more

    - `DOC /network/fc/wwpn-aliases`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves an FC WWPN alias.

    ### Related ONTAP commands

    - `vserver fcp wwpn-alias show`

    ### Learn more

    - `DOC /network/fc/wwpn-aliases`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates an FC WWPN alias.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the FC alias.
    - `alias` - Name of the FC alias.
    - `wwpn` - FC WWPN for which to create the alias.

    ### Related ONTAP commands

    - `vserver fcp wwpn-alias set`

    ### Learn more

    - `DOC /network/fc/wwpn-aliases`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class WwpnAliasSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the WwpnAlias object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `alias GET POST`

    The FC WWPN alias. Required in POST.

    Example: host1

  `links GET`

    The links field of the wwpn_alias.

  `svm GET POST PATCH`

    The svm field of the wwpn_alias.

  `wwpn GET POST`

    The FC initiator WWPN. Required in POST.

    Example: 2f:a0:00:a0:98:0b:56:13